.. _tutorial:

Tutorial
========

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   tutorial01
   tutorial02
   tutorial03             
   tutorial04
   tutorial05
   tutorial06
   tutorial07
   tutorial08


The tutorial is evolving, some things that will be covered in future
versions:

* Generating schemas from:

   - JSON Schema
   - OWL Ontologies
   - Instance data in JSON, TSV/spreadsheets, RDF
   
* SQL databases
* Using LinkML to organize spreadsheets
* Change objects and diffs
* Query APIs
